@@ -1,4 +1,5 @@
-%% Copyright (C) 2014-2016 Colin B. Macdonald
+%% Copyright (C) 2014-2017 Colin B. Macdonald
+%% Copyright (C) 2017 Lagu
 %%
 %% This file is part of OctSymPy.
 %%
@@ -18,8 +19,10 @@
 
 %% -*- texinfo -*-
 %% @documentencoding UTF-8
-%% @deftypemethod  @@sym {@var{x} =} assumeAlso (@var{x}, @var{cond}, @var{cond2}, ...)
+%% @deftypemethod  @@sym {@var{x} =} assumeAlso (@var{x}, @var{cond}, @var{cond2}, @dots{})
+%% @deftypemethodx @@sym {[@var{x}, @var{y}] =} assumeAlso ([@var{x} @var{y}], @var{cond}, @dots{})
 %% @deftypemethodx @@sym {} assumeAlso (@var{x}, @var{cond})
+%% @deftypemethodx @@sym {} assumeAlso ([@var{x} @var{y}], @var{cond}, @dots{})
 %% Add additional assumptions on a symbolic variable.
 %%
 %% Behaviour is similar to @code{assume}; however @var{cond} is combined
@@ -37,8 +40,6 @@
 %%     @}
 %%
 %% x = assumeAlso(x, 'positive');
-%% @c doctest: +SKIP
-%% @c (output order may depend on Python version here)
 %% assumptions(x)
 %%   @result{} ans =
 %%     @{
@@ -46,8 +47,6 @@
 %%     @}
 %% @end group
 %% @end example
-%% (Note the previous output will be more verbose if you are using
-%% an older version of SymPy before SymPy 1.0.)
 %%
 %% As with @code{assume}, note @code{x1} is unchanged:
 %% @example
@@ -67,51 +66,59 @@
 %% @seealso{@@sym/assume, assumptions, sym, syms}
 %% @end deftypemethod
 
-%% Author: Colin B. Macdonald
-%% Keywords: symbolic
 
-function varargout = assumeAlso(x, varargin)
+function varargout = assumeAlso(xx, varargin)
 
-  [tilde,ca] = assumptions(x, 'dict');
+  assert (nargin > 1, 'assumeAlso: general algebraic assumptions are not supported');
 
-  if isempty(ca)
-    ca = [];
-  elseif (length(ca)==1)
-    ca = ca{1};
-  else
-    ca
-    error('expected at most one dict')
+  for n = 2:nargin
+    assert (ischar (varargin{n-1}), 'assumeAlso: conditions should be specified as strings')
   end
 
-  for n=2:nargin
-    cond = varargin{n-1};
-    ca.(cond) = true;
+  for i = 1:numel (xx)
+    x = subsref (xx, substruct('()', {i}));
+
+    [tilde,ca] = assumptions(x, 'dict');
+
+    if isempty(ca)
+      ca = [];
+    elseif (length(ca)==1)
+      ca = ca{1};
+    else
+      ca
+      error('expected at most one dict')
+    end
+
+    for n=2:nargin
+      cond = varargin{n-1};
+      ca.(cond) = true;
+    end
+
+    xstr = x.flat;
+    newx = sym(xstr, ca);
+
+    if (nargout > 0)
+      varargout{i} = newx;
+    else
+
+      % ---------------------------------------------
+      % Muck around in the caller's namespace, replacing syms
+      % that match 'xstr' (a string) with the 'newx' sym.
+      %xstr =
+      %newx =
+      context = 'caller';
+      % ---------------------------------------------
+      S = evalin(context, 'whos');
+      evalin(context, '[];');  % clear 'ans'
+      for i = 1:numel(S)
+        obj = evalin(context, S(i).name);
+        [newobj, flag] = symreplace(obj, xstr, newx);
+        if flag, assignin(context, S(i).name, newobj); end
+      end
+      % ---------------------------------------------
+
+    end
   end
-
-  xstr = x.flat;
-  newx = sym(xstr, ca);
-
-  if (nargout > 0)
-    varargout{1} = newx;
-    return
-  end
-
-  % ---------------------------------------------
-  % Muck around in the caller's namespace, replacing syms
-  % that match 'xstr' (a string) with the 'newx' sym.
-  %xstr =
-  %newx =
-  context = 'caller';
-  % ---------------------------------------------
-  S = evalin(context, 'whos');
-  evalin(context, '[];');  % clear 'ans'
-  for i = 1:numel(S)
-    obj = evalin(context, S(i).name);
-    [newobj, flag] = symreplace(obj, xstr, newx);
-    if flag, assignin(context, S(i).name, newobj); end
-  end
-  % ---------------------------------------------
-
 end
 
 
@@ -121,6 +128,10 @@ end
 %! a = assumptions(x);
 %! assert(strcmp(a, 'x: positive'))
 
+%!error <strings>
+%! syms x
+%! x = assumeAlso (x, x);
+
 %!test
 %! syms x positive
 %! x = assumeAlso(x, 'integer');
@@ -137,9 +148,17 @@ end
 %! assert(a{1}.positive)
 %! assert(a{1}.even)
 
+%!test
+%! % multiple assumptions
+%! syms x integer
+%! x = assumeAlso (x, 'even', 'positive');
+%! [tilde, a] = assumptions (x, 'dict');
+%! assert (a{1}.integer)
+%! assert (a{1}.even)
+%! assert (a{1}.positive)
+
 %!test
 %! % has output so avoids workspace
-%! if (python_cmd ('return Version(spver) >= Version("1.0")'))
 %! syms x positive
 %! x2 = x;
 %! f = sin(x);
@@ -150,11 +169,9 @@ end
 %! assert(strcmp(a, 'x: positive, integer') || strcmp(a, 'x: integer, positive'))
 %! a = assumptions(f);
 %! assert(strcmp(a, 'x: positive, integer') || strcmp(a, 'x: integer, positive'))
-%! end
 
 %!test
 %! % has no output so does workspace
-%! if (python_cmd ('return Version(spver) >= Version("1.0")'))
 %! syms x positive
 %! x2 = x;
 %! f = sin(x);
@@ -165,4 +182,32 @@ end
 %! assert(strcmp(a, 'x: positive, integer') || strcmp(a, 'x: integer, positive'))
 %! a = assumptions(f);
 %! assert(strcmp(a, 'x: positive, integer') || strcmp(a, 'x: integer, positive'))
-%! end
+
+%!error <algebraic assumptions are not supported>
+%! syms a
+%! assumeAlso (a > 0)
+
+%!test
+%! syms x y
+%! assumeAlso ([x y], 'even')
+%! assert (strcmp (assumptions (x), 'x: even'))
+%! assert (strcmp (assumptions (y), 'y: even'))
+
+%!test
+%! syms x y positive
+%! f = sin (2*x);
+%! assumeAlso ([x y], 'even')
+%! assert (strcmp (assumptions (x), 'x: even, positive') || strcmp (assumptions (x), 'x: positive, even'))
+%! assert (strcmp (assumptions (y), 'y: even, positive') || strcmp (assumptions (y), 'y: positive, even'))
+%! assert (strcmp (assumptions (f), 'x: even, positive') || strcmp (assumptions (f), 'x: positive, even'))
+
+%!test
+%! % with output, original x and y are unchanged
+%! syms x y positive
+%! f = sin (2*x);
+%! [p, q] = assumeAlso ([x y], 'even');
+%! assert (strcmp (assumptions (x), 'x: positive'))
+%! assert (strcmp (assumptions (y), 'y: positive'))
+%! assert (strcmp (assumptions (f), 'x: positive'))
+%! assert (strcmp (assumptions (p), 'x: even, positive') || strcmp (assumptions (p), 'x: positive, even'))
+%! assert (strcmp (assumptions (q), 'y: even, positive') || strcmp (assumptions (q), 'y: positive, even'))
