@@ -88,7 +88,7 @@ function t = eq(x, y)
     print_usage ();
   end
 
-  t = ineq_helper('[donotuse]', 'Eq', x, y);
+  t = ineq_helper('[donotuse]', 'Eq', sym(x), sym(y));
 
 end
 
@@ -167,3 +167,10 @@ end
 %! e = a' == b';
 %! eexp = eexp.';  % is/was bug here with '
 %! assert (isequal (e, eexp))
+
+%!test
+%! % empty matrices compare to correct empty size
+%! a = zeros (sym(3), 0);
+%! assert (size (a == a), [3, 0])
+%! a = zeros (sym(0), 2);
+%! assert (size (a == a), [0, 2])
