@@ -1,4 +1,4 @@
-%% Copyright (C) 2014-2017, 2019 Colin B. Macdonald
+%% Copyright (C) 2014-2017, 2019, 2022 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -95,15 +95,15 @@
 %%       @@(x) exp (sin (x))
 %% @end group
 %%
+%% @c doctest: +SKIP_IF(compare_versions (OCTAVE_VERSION(), '6.0.0', '<'))
 %% @group
 %% fh(linspace(0, 2*pi, 700)')
 %%   @result{} ans =
-%%       ...
-%%       1.00903
-%%       1.01814
-%%       1.02733
-%%       1.03660
-%%       1.04595
+%%       1.0000
+%%       1.0090
+%%       1.0181
+%%       1.0273
+%%       1.0366
 %%       ...
 %% @end group
 %% @end example
@@ -230,7 +230,7 @@ function g = subs(f, in, out)
   %if (isscalar(in) && isscalar(in) && isscalar(out))
   %  cmd = { '(f, x, y) = _ins'
   %          'return f.subs(x, y).doit(),' };
-  %  g = python_cmd (cmd, sym(f), sym(in), sym(out));
+  %  g = pycall_sympy__ (cmd, sym(f), sym(in), sym(out));
   %  return
   %end
 
@@ -256,20 +256,22 @@ function g = subs(f, in, out)
     'sizes = {(a.shape if a.is_Matrix else (1, 1)) for a in yy}'
     'sizes.discard((1, 1))'
     'assert len(sizes) == 1, "all substitions must be same size or scalar"'
-    'g = zeros(*sizes.pop())'
+    'size = sizes.pop()'
+    'numel = prod(size)'
+    'g = [0]*numel'
     'for i in range(len(g)):'
     '    yyy = [y[i] if y.is_Matrix else y for y in yy]'
     '    sublist = list(zip(xx, yyy))'
     '    g[i] = f.subs(sublist, simultaneous=True).doit()'
-    'return g'
+    'return Matrix(*size, g)'
   };
 
-  g = python_cmd (cmd, f, in, out);
+  g = pycall_sympy__ (cmd, f, in, out);
 
 end
 
 
-%!error <Invalid> subs (sym(1), 2, 3, 4)
+%!error subs (sym(1), 2, 3, 4)
 
 %!shared x,y,t,f
 %! syms x y t
