@@ -1,14 +1,16 @@
-# Copyright (C) 2014-2017, 2019 Colin B. Macdonald
+# Copyright (C) 2014-2017, 2019, 2021-2022 Colin B. Macdonald
 # Copyright (C) 2019 Mike Miller
+# Copyright (C) 2020 Tianyu Chen (billchenchina)
+# Copyright (C) 2021 Johannes Maria Frank
+# Copyright (C) 2022 Chris Gorman
+# Copyright (C) 2022 Alex Vong
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 # In some cases this code is fed into stdin: two blank lines between
 # try-except blocks, no blank lines within each block.
 
-from __future__ import print_function
-from __future__ import division
-
 import sys
+
 sys.ps1 = ""; sys.ps2 = ""
 
 
@@ -25,6 +27,7 @@ def echo_exception_stdout(mystr):
 
 try:
     import sympy
+    import mpmath
     import sympy as sp
     from sympy import __version__ as spver
     # need this to reactivate from srepr
@@ -38,20 +41,39 @@ try:
     # for hypergeometric
     from sympy.functions.special.hyper import TupleArg
     # for sets
-    from sympy.sets.fancysets import *
-    from sympy.sets.sets import *
     from sympy.utilities.iterables import uniq
+    try:
+        # quick fix for https://github.com/cbm755/octsympy/issues/1053
+        # TODO: investigate the sym ctor in this case, likely a better fix in there
+        from sympy.core.symbol import Str
+    except ImportError:
+        pass
     import copy
     import binascii
     import struct
     import codecs
     import xml.etree.ElementTree as ET
-    from distutils.version import LooseVersion
+    try:
+        from packaging.version import Version
+    except ImportError:
+        try:
+            # available on SymPy >= 1.9
+            from sympy.external.importtools import version_tuple as Version
+        except ImportError:
+            # will fail on Python 3.12: drop this soon in favour of above
+            from distutils.version import LooseVersion
+            def Version(v):
+                return LooseVersion(v.replace('.dev', ''))
     import itertools
     import collections
     from re import split
     # patch pretty printer, issue #952
-    _mypp = pretty.__globals__["PrettyPrinter"]
+    try:
+        from sympy.printing.pretty.pretty import PrettyPrinter
+        _mypp = PrettyPrinter
+    except:
+        # is this needed for SymPy 1.4?  TODO: Bump minimum SymPy and cleanup
+        _mypp = pretty.__globals__["PrettyPrinter"]
     def _my_rev_print(cls, f, **kwargs):
         g = f.func(*reversed(f.args), evaluate=False)
         return cls._print_Function(g, **kwargs)
@@ -65,35 +87,21 @@ except:
 
 try:
     def dbout(l):
+        # should be kept in sync with the same function
+        # defined in inst/private/python_ipc_native.m
         sys.stderr.write("pydebug: " + str(l) + "\n")
     def d2hex(x):
-        # used to pass doubles back-and-forth (.decode for py3)
+        # used to pass doubles back-and-forth
         return binascii.hexlify(struct.pack(">d", x)).decode()
     def hex2d(s):
-        if sys.version_info >= (3, 0):
-            bins = bytes([int(s[x:x+2], 16) for x in range(0, len(s), 2)])
-        else:
-            bins = "".join(chr(int(s[x:x+2], 16)) for x in range(0, len(s), 2))
+        bins = bytes([int(s[x:x+2], 16) for x in range(0, len(s), 2)])
         return struct.unpack(">d", bins)[0]
-    def dictdiff(a, b):
-        """ keys from a that are not in b, used by evalpy() """
-        n = dict()
-        for k in a:
-            if not k in b:
-                n[k] = a[k]
-        return n
-    def Version(v):
-        # short but not quite right: https://github.com/cbm755/octsympy/pull/320
-        return LooseVersion(v.replace('.dev', ''))
     def myesc(s):
-        if sys.version_info >= (3, 0):
-            # workaround https://bugs.python.org/issue25270
-            if not s:
-                return s
-            b, n = codecs.escape_encode(s.encode('utf-8'))
-            return b.decode('ascii')
-        else:
-            return s.encode('utf-8').encode('string_escape')
+        # workaround https://bugs.python.org/issue25270
+        if not s:
+            return s
+        b, _ = codecs.escape_encode(s.encode('utf-8'))
+        return b.decode('ascii')
 except:
     echo_exception_stdout("in python_header defining fcns block 1")
     raise
@@ -118,10 +126,7 @@ try:
         import xml.dom.minidom as minidom
         DOM = minidom.parseString(ET.tostring(xroot))
         # want real newlines here (so hard to do escaping *after* this)
-        if sys.version_info >= (3, 0):
-            s = DOM.toprettyxml(indent="", newl="\n")
-        else:
-            s = DOM.toprettyxml(indent="", newl="\n", encoding="utf-8")
+        s = DOM.toprettyxml(indent="", newl="\n")
         if tostdout:
             print(s)
         else:
@@ -185,7 +190,7 @@ try:
             c = ET.SubElement(et, "list")
             for y in x:
                 octoutput(y, c)
-        elif isinstance(x, sp.compatibility.integer_types):
+        elif isinstance(x, int):
             a = ET.SubElement(et, "item")
             f = ET.SubElement(a, "f")
             f.text = str(OCTCODE_INT)
@@ -206,7 +211,7 @@ try:
             f.text = d2hex(x.real)
             f = ET.SubElement(a, "f")
             f.text = d2hex(x.imag)
-        elif isinstance(x, sp.compatibility.string_types):
+        elif isinstance(x, str):
             a = ET.SubElement(et, "item")
             f = ET.SubElement(a, "f")
             f.text = str(OCTCODE_STR)
@@ -224,10 +229,7 @@ try:
             octoutput(keystr, c)
             c = ET.SubElement(a, "list")
             # FIXME: bit of a kludge, use iterable instead of list, tuple above?
-            if sys.version_info >= (3, 0):
-                octoutput(list(x.values()), c)
-            else:
-                octoutput(x.values(), c)
+            octoutput(list(x.values()), c)
         else:
             raise ValueError("octoutput does not know how to export type " + str(type(x)))
 except:
